@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ox-beamer-lecture" "1.0"
+(define-package "ox-beamer-lecture" "20250918.358"
   "Beamer Lecture Back-End for Org Export Engine."
   '((emacs "29.1"))
   :url "https://github.com/fjesser/ox-beamer-lecture"
-  :commit "77546eaf9ac8f94b6079720f1d93c33dbbcc4108"
-  :revdesc "1.0-0-g77546eaf9ac8"
+  :commit "d9cb630ab5d9e5ef58f68216a4b9e472d67eb46e"
+  :revdesc "d9cb630ab5d9"
   :keywords '("org" "text" "tex")
   :authors '(("Felix J. Esser" . "code-esser@mailbox.org"))
   :maintainers '(("Felix J. Esser" . "code-esser@mailbox.org")))
