@@ -6,8 +6,8 @@
 ;; Maintainer: Felix J. Esser <code-esser@mailbox.org>
 ;; URL: https://github.com/fjesser/ox-beamer-lecture
 ;; Created: 2025
-;; Package-Version: 1.0
-;; Package-Revision: 1.0-0-g77546eaf9ac8
+;; Package-Version: 20250918.358
+;; Package-Revision: d9cb630ab5d9
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: org, text, tex
 
@@ -71,6 +71,7 @@
   :group 'org-export-beamer-lecture
   :version "29.4")
 
+;; Group: org-export-beamer-lecture
 (defcustom org-beamer-lecture-frame-level 3
   "The level at which headlines become frames.
 
@@ -139,9 +140,24 @@ Handout files do not contain overlays nor notes. It has the form
   :group 'org-export-beamer-lecture
   :type 'string)
 
+(defcustom org-beamer-lecture-auctex-add-local nil
+  "Whether to include file local variables for AUCTeX in slides.
+
+If t, file local variables are included at the end of the presentation
+tex files (beamer and handout) so that it is possible to compile them
+directly. Otherwise, running AUCTeX will fail because of the folder
+structure introduced by org-beamer-lecture.
+
+It can be set with the in-buffer options setting `#+OPTIONS: auctex:t'.
+The template for the local variables is defined in
+`org-beamer-lecture--auctex-variables-template'."
+  :group 'org-export-beamer-lecture
+  :type 'boolean)
+
+;; Group: org-export-beamer-lecture-article
 (defcustom org-beamer-lecture-article-suffix "-article"
   "Suffix for files of article export."
-  :group 'org-export-beamer-lecture
+  :group 'org-export-beamer-lecture-article
   :type 'string)
 
 (defcustom org-beamer-lecture-article-rename-chapter t
@@ -219,6 +235,26 @@ for each lecture.")
 The variable will be populated with beamer and handout tex files
 which should be compiled.")
 
+(defvar org-beamer-lecture--auctex-variables-template (concat "
+%%% Local Variables:
+%%% mode: LaTeX
+%%% eval: (add-to-list 'TeX-command-list '(\"LaTeXMk-ox-beamer-lecture\""
+" \"cd ..; latexmk %(latexmk-out) %(file-line-error)"
+" %`%(extraopts) %S%(mode)%' %t\""
+" TeX-run-TeX nil (LaTeX-mode docTeX-mode) :help \"Run MyLaTeXMk\"))
+%%% TeX-command-default: \"LaTeXMk-ox-beamer-lecture\"
+%%% TeX-command-extra-options: \"--output-directory='%D'\"
+%%% End:
+")
+  "Template for AUCTeX file local variables used in presentation slides.
+
+Depending on `org-beamer-lecture-auctex-add-local' this template is
+added at the end of the presentation slides which makes it possible to
+compile tex files directly. `%D' will be expanded to the corresponding
+output directory within `org-beamer-lecture-template'.
+`TeX-command-extra-options' is chosen over `TeX-output-dir' because the
+latter would impede other AUCTeX commands like Clean.")
+
 
 ;;; Internal Functions
 
@@ -403,7 +439,8 @@ was compiled or raise an error if it couldn't be produced."
     ;; --- Beamer Export Settings
     ;; --- Beamer Lecture Export Settings
     (:headline-levels nil "H" org-beamer-lecture-frame-level)
-    (:beamer-lecture-label "BEAMER_LECTURE_LABEL" nil org-beamer-lecture-label))
+    (:beamer-lecture-label "BEAMER_LECTURE_LABEL" nil org-beamer-lecture-label)
+    (:beamer-lecture-auctex nil "auctex" org-beamer-lecture-auctex-add-local))
   :translate-alist
   '((headline . org-beamer-lecture-headline)
     (plain-list . org-beamer-lecture-plain-list)
@@ -609,48 +646,56 @@ is no template available."
         (org-latex-title-command "\\begin{frame}\n\\maketitle\\end{frame}")
         (index 0)) ; Index for while loop
     ;; Check whether input number is allowed
-    (when (or (< org-beamer-lecture--lecture-number 0)
+    (when (or (< org-beamer-lecture--lecture-number -1)
               (> org-beamer-lecture--lecture-number (length lecture-labels)))
       (error "Lecture number %s does not exist" org-beamer-lecture--lecture-number))
-    ;; Loop over selected lectures
-    (while (< index (length lecture-labels))
-      (let* ((lecture (nth index lecture-labels))
-             (label (car lecture))
-             (title (cdr lecture))
-             (title-dir (org-beamer-lecture--transform-title title)))
-        (when (or (= org-beamer-lecture--lecture-number 0)
-                  (= (1- org-beamer-lecture--lecture-number) index))
-          ;; Use overall title for subtitle
-          (when org-beamer-lecture-title-as-subtitle
-            (plist-put info :subtitle (plist-get info :title)))
-          ;; Use lecture title for lecture and remove latex code
-          (plist-put info :title (org-beamer-lecture-remove-latex
-                                  title))
-          ;; Use EXPORT_DATE property of lecture
-          (plist-put info :date `(,(nth index org-beamer-lecture--dates)))
-          ;; Create and process tex files
-          (let* ((outdir (concat label "-" title-dir))
-                 (base-outfile (file-name-concat outdir outdir))
-                 (beamer-texfile (concat base-outfile
-                                         org-beamer-lecture-beamer-suffix
-                                         ".tex") )
-                 (handout-texfile (concat base-outfile
-                                          org-beamer-lecture-handout-suffix
-                                          ".tex"))
-                 (slides-body (format "\\mode<all>{\\input{../%s}}\n\n"
-                                      (plist-get info :output-file)))
-                 ;; Logic taken from org-export-as
-                 (tex-template (if (plist-get info :with-cite-processors)
-                                   (org-cite-finalize-export
-                                    (org-beamer-template slides-body info)
-                                    info)
-                                 (org-beamer-template slides-body info))))
-            ;; Create directory
-            (unless (file-directory-p outdir)
-              (make-directory outdir))
-            ;; Create beamer tex file
-            ;; (format) throws error with LaTeX comments. Use (format-spec)
-            ;; with ignore-missing
+    (unless (eq org-beamer-lecture--lecture-number -1)
+      ;; Loop over selected lectures
+      (while (< index (length lecture-labels))
+        (let* ((lecture (nth index lecture-labels))
+               (label (car lecture))
+               (title (cdr lecture))
+               (title-dir (org-beamer-lecture--transform-title title)))
+          (when (or (= org-beamer-lecture--lecture-number 0)
+                    (= (1- org-beamer-lecture--lecture-number) index))
+            ;; Use overall title for subtitle
+            (when org-beamer-lecture-title-as-subtitle
+              (plist-put info :subtitle (plist-get info :title)))
+            ;; Use lecture title for lecture and remove latex code
+            (plist-put info :title (org-beamer-lecture-remove-latex
+                                    title))
+            ;; Use EXPORT_DATE property of lecture
+            (plist-put info :date `(,(nth index org-beamer-lecture--dates)))
+            ;; Create and process tex files
+            (let* ((outdir (concat label "-" title-dir))
+                   (base-outfile (file-name-concat outdir outdir))
+                   (beamer-texfile (concat base-outfile
+                                           org-beamer-lecture-beamer-suffix
+                                           ".tex") )
+                   (handout-texfile (concat base-outfile
+                                            org-beamer-lecture-handout-suffix
+                                            ".tex"))
+                   (slides-body (format "\\mode<all>{\\input{../%s}}\n\n"
+                                        (plist-get info :output-file)))
+                   ;; Logic taken from org-export-as
+                   (tex-template (concat
+                                  (if (plist-get info :with-cite-processors)
+                                      (org-cite-finalize-export
+                                       (org-beamer-template slides-body info)
+                                       info)
+                                    (org-beamer-template slides-body info))
+                                  (when org-beamer-lecture-auctex-add-local
+                                    "\n"
+                                    (format-spec
+                                     org-beamer-lecture--auctex-variables-template
+                                     `((?D . ,outdir))
+                                     t)))))
+              ;; Create directory
+              (unless (file-directory-p outdir)
+                (make-directory outdir))
+              ;; Create beamer tex file
+              ;; (format) throws error with LaTeX comments. Use (format-spec)
+              ;; with ignore-missing
             (with-temp-file beamer-texfile
               (insert (format-spec tex-template
                                    `((?h . "")
@@ -668,7 +713,7 @@ is no template available."
       (setq index (1+ index)))
     ;; Correct order of lectures to compile
     (setq org-beamer-lecture--to-compile
-          (nreverse org-beamer-lecture--to-compile)))
+          (nreverse org-beamer-lecture--to-compile))))
   ;; Only output contents, previous code is for side effects
   (concat
    (when (plist-get info :time-stamp-file)
@@ -799,6 +844,54 @@ plist holding export options."
      ;; Document end.
      "\\end{document}")))
 
+
+;;; Commands
+
+;;;###autoload
+(defun org-beamer-lecture-export-as-latex
+    (&optional async subtreep visible-only body-only ext-plist)
+  "Export current buffer as a Beamer Lecture tex buffer.
+
+The content is the body which is inputted within the presentation and
+handout tex files.
+
+The user is prompted for the lecture number which creates the
+corresponding folder with the beamer and handout slides. Entering
+0 creates all possible folders and files.
+
+If narrowing is active in the current buffer, only export its
+narrowed part.
+
+If a region is active, export that region.
+
+A non-nil optional argument ASYNC means the process should happen
+asynchronously.  The resulting file should be accessible through
+the `org-export-stack' interface.
+
+When optional argument SUBTREEP is non-nil, export the sub-tree
+at point, extracting information from the headline properties
+first.
+
+When optional argument VISIBLE-ONLY is non-nil, don't export
+contents of hidden elements.
+
+When optional argument BODY-ONLY is non-nil, only write code
+between \"\\begin{document}\" and \"\\end{document}\". In this
+case no folder and files will be created, only the texfile
+containing the document's body will be created.
+
+EXT-PLIST, when provided, is a property list with external
+parameters overriding Org default settings, but still inferior to
+file-local settings.
+
+Return output file's name."
+  (interactive)
+  (let ((org-beamer-lecture--lecture-number -1)
+        (org-beamer-lecture--to-compile nil))
+    (org-export-to-buffer 'beamer-lecture
+        "*Org BEAMER LECTURE Presentation Export*"
+      async subtreep visible-only body-only ext-plist
+      (lambda () (LaTeX-mode)))))
 
 ;;;###autoload
 (defun org-beamer-lecture-export-to-latexs
